{% if messages %}
<!-- begin alert messages -->
<div class="col-md-12">
{% for message in messages %}
    {% if message.level == DEFAULT_MESSAGE_LEVELS.ERROR %}
    <div class="alert alert-danger alert-dismissable fade in">
    <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
      <i class="fas fa-hand-paper fa-lg"></i> {{ message }}
    </div>
    {% endif %}
    {% if message.level == DEFAULT_MESSAGE_LEVELS.WARNING %}
    <div class="alert alert-warning alert-dismissable fade in">
    <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
      <i class="fas fa-hand-point-right fa-lg"></i> {{ message }}
    </div>
    {% endif %}
    {% if message.level == DEFAULT_MESSAGE_LEVELS.SUCCESS %}
    <div class="alert alert-success alert-dismissable fade in">
    <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
      <i class="fas fa-thumbs-up fa-lg"></i> {{ message }}
    </div>
    {% endif %}
    {% if message.level == DEFAULT_MESSAGE_LEVELS.INFO %}
    <div class="alert alert-info alert-dismissable fade in">
    <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
      <i class="fas fa-info-circle fa-lg"></i> {{ message }}
    </div>
    {% endif %}
{% endfor %}</div><!-- end alert messages -->
{% endif %}
