{% extends 'edc_dashboard/bootstrap3/base.html' %}
{% load i18n %}

{% block extrastyle %}
{{ block.super }}
<style>
  h1 {
    font-size: 1200%;
    font-weight: 900;
  }
  #error-page {
    padding-top: 10%;
    text-align: center
  }
  </style>
{% endblock extrastyle %}

{% block main %}
    <div id="error-page" class="col-md-12">
        <h1>403</h1>
        <h2>Forbidden</h2>
        <br>
        <a class="btn btn-primary" onclick="window.history.back();">{% trans "Go Back" %}</a>&nbsp;or&nbsp;
        <a class="btn btn-primary" href="/">{% trans "Return to the home page" %}</a>
    </div>
{% endblock main %}

{% block alert %}{% endblock alert %}

{% block topbar_title %}{% endblock topbar_title %}
