{% load tz %}
<!-- begin edc dashboard custom footer -->
<div id="footer">
<footer class="footer">
    <div class="container">
        {% block footer_extra_items %}
        {% endblock footer_extra_items %}
        <div class="col-md-3"><p class="text-muted small text-center">
            {% include 'edc_dashboard/bootstrap3/set_language.html' %}
            <span class="fa-solid fa-copyright"></span> Licensed for use under
            <A href="https://www.gnu.org/licenses/gpl-3.0.en.html">GPL 3.0</A></p></div>
        <div class="col-md-3"><p class="text-muted small text-center">
            <span class="fa-solid fa-leaf"></span> Revision: {{ revision }}</p></div>
        <div class="col-md-3"><p class="text-muted small text-center">
            <span class="fa-solid fa-clock"></span> {% now "SHORT_DATETIME_FORMAT" %} {% get_current_timezone as TIME_ZONE %} {{ TIME_ZONE }}
        </p></div>
        <div class="col-md-3"><p class="text-muted small text-center">
            <span class="fa-solid fa-exclamation"></span> {{ disclaimer }}</p>
        </div>
    </div>
</footer>
</div>
<!-- end edc dashboard custom footer -->
