{% extends "edc_dashboard/bootstrap3/base_dj4.html" %}
{% load edc_navbar_extras %}
{% load static %}
{% load tz %}
{% load i18n %}
{% block title %}{{ project_name|default_if_none:"clinicedc.org" }}{% endblock title %}

{% block jquery %}
   {% if DEBUG %}
     <script src="{% static 'admin/js/vendor/jquery/jquery.js' %}"></script>
   {% else %}
     <script src="{% static 'admin/js/vendor/jquery/jquery.min.js' %}"></script>
   {% endif %}
 {% endblock %}

{% block extrastyle %}
    {{ block.super }}
    <script src="{% static 'fontawesomefree/js/all.min.js' %}"></script>
    <!-- favicon -->
    <link rel="icon" href="{% static 'edc_dashboard/icons/favicon.ico' %}">
    <link rel="shortcut icon" href="{% static 'edc_dashboard/icons/favicon.ico' %}" type="image/x-icon"/>
    <link rel="apple-touch-icon" href="{% static 'edc_dashboard/icons/apple-touch-icon.png' %}"/>
    <link rel="apple-touch-icon" sizes="57x57" href="{% static 'edc_dashboard/icons/apple-touch-icon-57x57.png' %}"/>
    <link rel="apple-touch-icon" sizes="72x72" href="{% static 'edc_dashboard/icons/apple-touch-icon-72x72.png' %}"/>
    <link rel="apple-touch-icon" sizes="76x76" href="{% static 'edc_dashboard/icons/apple-touch-icon-76x76.png' %}"/>
    <link rel="apple-touch-icon" sizes="114x114" href="{% static 'edc_dashboard/icons/apple-touch-icon-114x114.png' %}"/>
    <link rel="apple-touch-icon" sizes="120x120" href="{% static 'edc_dashboard/icons/apple-touch-icon-120x120.png' %}"/>
    <link rel="apple-touch-icon" sizes="144x144" href="{% static 'edc_dashboard/icons/apple-touch-icon-144x144.png' %}"/>
    <link rel="apple-touch-icon" sizes="152x152" href="{% static 'edc_dashboard/icons/apple-touch-icon-152x152.png' %}"/>
    <link rel="apple-touch-icon" sizes="180x180" href="{% static 'edc_dashboard/icons/apple-touch-icon-180x180.png' %}"/>

    <!-- Latest bootstrap compiled and minified CSS -->
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/3.4.1/css/bootstrap.min.css" integrity="sha384-HSMxcRTRxnN+Bdg0JdbxYKrThecOKuH5zCYotlSAcp1+c8xmyTe9GYg1l9a69psu" crossorigin="anonymous">
    <!-- Optional bootstrap theme -->
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/3.4.1/css/bootstrap-theme.min.css" integrity="sha384-6pzBo3FDv/PJ8r2KRkGHifhEocL+1X2rVCTTkUfGk7/0pbek5mMa1upzvWbrUbOZ" crossorigin="anonymous">

    <!-- EDC themes -->
    <link rel="stylesheet" type="text/css" href="{% static 'edc_dashboard/css/sticky-footer-navbar.css' %}">

    <!-- Latest compiled and minified JavaScript -->
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/3.4.1/js/bootstrap.min.js" integrity="sha384-aJ21OjlMXNL5UyIl/XNwTMqvzeRMZH2w8c5cRVpzpU8Y5bApTppSuUkhZXN0VxHd" crossorigin="anonymous"></script>

    <!-- IE10 viewport hack for Surface/desktop Windows 8 bug -->
    <script type="text/javascript" charset="utf8" src="{% static 'edc_dashboard/js/ie10-viewport-bug-workaround.js' %}"></script>
    <script type="text/javascript" charset="utf8" src="{% static 'edc_dashboard/js/edc.js' %}"></script>

    <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/html5shiv/3.7.3/html5shiv.min.js"></script>
      <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
    <![endif]-->
{% endblock extrastyle %}

{% block document_ready %}
    <script>
        $(document).ready(function () {
            $('[data-toggle="tooltip"]').tooltip();
            $('[data-toggle="popover"]').popover({html: true, trigger: 'focus'});
            $("#success-alert").fadeTo(1000, 500).slideUp(500, function () {
                $("#success-alert").slideUp(500);
            });
        });
    </script>
{% endblock document_ready %}

{% block topbar %}

    <!-- topbar -->
    <nav class="navbar navbar-inverse navbar-fixed-top">

        <div class="container-fluid">

            <div class="navbar-header">

                <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#navbar" aria-expanded="false" aria-controls="navbar">
                    <span class="sr-only">Toggle navigation</span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                </button>

                {% block topbar_title %}
                  {% include "edc_dashboard/bootstrap3/navbar_topbar_title.html" %}
                {% endblock topbar_title %}

            </div>


            {% block topbar_navbar_apps %}
                {% show_edc_navbar %}
            {% endblock topbar_navbar_apps %}

        </div>
    </nav>
    <!-- end topbar -->
{% endblock topbar %}

{% block alert %}{% include "edc_dashboard/bootstrap3/alert_messages.html" %}{% endblock alert %}

{% block modals %}
        {{ block.super }}
    {% include 'edc_dashboard/bootstrap3/help_modal.html' %}
{% endblock modals %}


{% block footer %}
    {% include 'edc_dashboard/bootstrap3/footer.html' %}
{% endblock footer %}
